/* jshint node:true, esversion: 6 */
'use strict';

var AbortTask = require('./utils/abort-task');
var GetPlatSizes = require('./utils/get-platform-sizes');
var PlatformSizes = require('./platform-icon-sizes');
var SerializeIcon = require('./utils/serialize-icon');
var UpdateConfig = require('./utils/update-config');
var ValidPlatform = require('./utils/validate-platforms');
var WriteImages = require('./utils/write-images');

var RSVP = require('rsvp');
var existsSync = require('fs').existsSync;
var _defaults = require('lodash').defaults;

module.exports = function (opts) {
  return new RSVP.Promise(function (resolve) {
    if (opts === undefined) opts = {};

    _defaults(opts, {
      source: 'icon.svg',
      dest: 'res/icon',
      projectPath: './cordova',
      platforms: ['all']
    });

    if (!existsSync(opts.source)) {
      AbortTask('Source icon ' + opts.source + ' does not exist');
    }

    if (!ValidPlatform(opts.platforms)) {
      AbortTask('Platforms ' + opts.platforms + ' are not all valid');
    }

    if (opts.platforms.length === 0 || opts.platforms.indexOf('all') > -1) {
      opts.platforms = ['ios', 'android', 'windows', 'blackberry'];
    }

    var platformSizes = GetPlatSizes(PlatformSizes, opts.platforms);

    WriteImages({
      source: opts.source,
      projectPath: opts.projectPath,
      dest: opts.dest,
      platformSizes: platformSizes
    }).then(function (updatedPlatformSizes) {
      UpdateConfig({
        projectPath: opts.projectPath,
        desiredNodes: updatedPlatformSizes,
        keyName: 'icon',
        serializeFn: SerializeIcon
      });
    }).then(resolve);
  });
};