/* jshint node:true, esversion: 6 */
'use strict';

var fs = require('fs');
var RSVP = require('rsvp');
var svg2png = require('../../vendor/svg2png/svg2png');

module.exports = function (options) {
  return new RSVP.Promise(function (resolve) {
    var buffer = fs.readFileSync(options.src);
    var rasterizeTasks = [];

    options.toRasterize.forEach(function (rasterize) {
      var width = void 0,
          height = void 0;
      if (rasterize.size) {
        width = rasterize.size;
        height = rasterize.size;
      } else {
        width = rasterize.width;
        height = rasterize.height;
      }

      var rasterizeTask = svg2png(buffer, { width: width, height: height }).then(function (pngBuffer) {
        fs.writeFileSync(rasterize.path, pngBuffer);
      });

      rasterizeTasks.push(rasterizeTask);
    });

    RSVP.all(rasterizeTasks).then(resolve);
  });
};