/* jshint node:true, esversion: 6 */
'use strict';

var MakeDir = require('./make-dir');
var svg2png = require('./svg2png');
var fs = require('fs');
var RSVP = require('rsvp');
var normalizePath = require('path').normalize;
var _forOwn = require('lodash').forOwn;
var _union = require('lodash').union;

module.exports = function (opts) {
  return new RSVP.Promise(function (resolve) {
    var buffer = fs.readFileSync(opts.source);
    var rasterizeTasks = [];
    var rasterizeQueue = [];

    _forOwn(opts.platformSizes, function (icons, platform) {
      MakeDir('./', opts.projectPath + '/' + opts.dest + '/' + platform);

      icons.sizes.map(function (size) {
        size.path = opts.dest + '/' + platform + '/' + size.name + '.png';
      });

      rasterizeQueue = _union(rasterizeQueue, icons.sizes);
    });

    rasterizeQueue.forEach(function (rasterize) {
      var width = void 0,
          height = void 0;

      if (rasterize.size) {
        width = rasterize.size;
        height = rasterize.size;
      } else {
        width = rasterize.width;
        height = rasterize.height;
      }

      var rasterizeTask = svg2png(buffer, { width: width, height: height }).then(function (pngBuffer) {
        var writePath = opts.projectPath + '/' + rasterize.path;
        fs.writeFileSync(normalizePath(writePath), pngBuffer);
      });

      rasterizeTasks.push(rasterizeTask);
    });

    RSVP.all(rasterizeTasks).then(function () {
      return resolve(opts.platformSizes);
    });
  });
};